import androidx.compose.animation.core.tween
import androidx.compose.animation.slideIn
import androidx.compose.animation.slideOut
import androidx.compose.runtime.Composable
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.unit.IntOffset
import androidx.navigation.NavGraph.Companion.findStartDestination
import androidx.navigation.NavHostController
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.toRoute
import fr.openium.consentium.api.Consentium
import fr.openium.consentium.ui.screens.main.MainScreen
import fr.openium.consentium.ui.screens.splash.SplashScreen
import fr.openium.consentium.ui.theme.Error
import fr.openium.consentium.ui.theme.OnPrimary
import fr.openium.consentium.ui.theme.OnSecondary
import fr.openium.consentium.ui.theme.OnSurface
import fr.openium.consentium.ui.theme.OnSurfaceVariant
import fr.openium.consentium.ui.theme.Primary
import fr.openium.consentium.ui.theme.Secondary
import fr.openium.consentium.ui.theme.Success
import fr.openium.consentium.ui.theme.SurfaceHigh
import fr.openium.consentium.ui.theme.SurfaceHighest
import fr.openium.consentium.ui.theme.SurfaceMiddle
import fr.openium.consentium.ui.theme.Tertiary
import fr.openium.consentium_ui.ui.components.ConsentiumComponent
import fr.openium.consentium_ui.ui.components.style.ConsentiumDefaults
import fr.openium.consentium_ui.ui.model.ConsentiumPageUI

private const val NAV_ANIMATION_TIME = 500

@Composable
fun DemoNavGraph(navHostController: NavHostController) {

    NavHost(
        navController = navHostController,
        startDestination = Destination.Splash,
        enterTransition = {
            slideIn(
                animationSpec = tween(NAV_ANIMATION_TIME),
                initialOffset = { fullSize -> IntOffset(x = fullSize.height, y = 0) }
            )
        },
        exitTransition = {
            slideOut(
                animationSpec = tween(NAV_ANIMATION_TIME),
                targetOffset = { fullSize -> IntOffset(x = -fullSize.height, y = 0) }
            )
        },
    ) {

        composable<Destination.Splash> {
            SplashScreen(
                navigateToMain = {
                    navHostController.navigate(Destination.Main) {
                        popUpTo(navHostController.graph.findStartDestination().id) {
                            saveState = true
                        }
                    }
                },
                navigateToConsent = {
                    navHostController.navigate(Destination.Consent(ConsentiumPageUI.GENERAL_CONSENT))
                }
            )
        }

        composable<Destination.Main> {
            MainScreen(
                onGoToConsentMaster = {
                    navHostController.navigate(Destination.Consent(ConsentiumPageUI.GENERAL_CONSENT))
                },
                onGoToConsentDetail = {
                    navHostController.navigate(Destination.Consent(ConsentiumPageUI.DETAILS_CONSENT))
                },
            )
        }

        composable<Destination.Consent> { backStackEntry ->
            val consent = backStackEntry.toRoute<Destination.Consent>()

            val context = LocalContext.current
            ConsentiumComponent(
                defaultLandingPage = consent.landingPage,
                onQuitConsent = {
                    navHostController.navigate(Destination.Main) {
                        popUpTo(navHostController.graph.findStartDestination().id) {
                            saveState = true
                        }
                    }
                },
                consentium = Consentium(
                    context = context,
                    applicationId = "ApplicationId",
                ),
                colors = ConsentiumDefaults.colors(
                    primary = Primary,
                    onPrimary = OnPrimary,
                    secondary = Secondary,
                    onSecondary = OnSecondary,
                    tertiary = Tertiary,
                    onSurfaceVariant = OnSurfaceVariant,
                    onSurface = OnSurface,
                    error = Error,
                    surfaceHighest = SurfaceHighest,
                    surfaceHigh = SurfaceHigh,
                    surfaceMiddle = SurfaceMiddle,
                    success = Success,
                )
            )
        }
    }
}
