package fr.openium.consentium.ui.screens.splash

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.size
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.unit.dp
import fr.openium.consentium.api.Consentium
import fr.openium.consentium.api.state.FetchConsentiumState

@Composable
fun SplashScreen(
    navigateToMain: () -> Unit,
    navigateToConsent: () -> Unit,
) {
    // Property
    val context = LocalContext.current
    val consentium = remember { Consentium(context = context, applicationId = "DemoApplicationId") }

    // Effect
    LaunchedEffect(Unit) {
        consentium.fetchConsentState.collect { consentState ->
            when (consentState) {
                FetchConsentiumState.Idle,
                FetchConsentiumState.Loading -> {}

                FetchConsentiumState.Error -> {
                    // Handle error
                    consentium.fetchConsents()
                }

                is FetchConsentiumState.Invalid -> {
                    navigateToConsent()
                }

                is FetchConsentiumState.Valid -> {
                    // The tracking services should be initialized here
                    navigateToMain()
                }
            }
        }
    }

    LaunchedEffect(Unit) {
        consentium.fetchConsents()
    }

    // View
    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Center
    ) {

        Text("Splash Screen") // TODO

        Spacer(modifier = Modifier.height(14.dp))

        CircularProgressIndicator(
            modifier = Modifier.size(40.dp)
        )

    }

}