package fr.openium.consentium_ui.data.remote.mock

import fr.openium.consentium_ui.data.remote.ConsentiumUIApi
import fr.openium.consentium_ui.data.remote.model.GetConsentConfigDTO
import fr.openium.consentium_ui.data.remote.model.MainConsentTextTranslationDTO
import fr.openium.consentium_ui.data.remote.model.PurposeDTO
import fr.openium.consentium_ui.data.remote.model.PurposeStatusDTO
import fr.openium.consentium_ui.data.remote.model.PurposeTranslationDTO
import fr.openium.consentium_ui.data.remote.model.VendorDTO
import fr.openium.consentium_ui.data.remote.model.VendorTranslationDTO
import retrofit2.Response
import java.util.UUID

internal object ConsentiumUIMockApi : ConsentiumUIApi {

    private val consents = GetConsentConfigDTO(
        installationId = UUID.randomUUID().toString(),
        appName = "Consentium",
        icon = "https://amp.openium.fr/openium.png",
        primaryColor = "#FF0000",
        secondaryColor = "#00FF00",
        textColor = "#0000FF",
        consentMainTextTranslation = listOf(
            MainConsentTextTranslationDTO(
                id = "UUID",
                language = "fr",
                consentPageUrl = "https://www.openium.fr",
                mainConsentText = "<p>[Nom de l’application] utilise des cookies pour différents objectifs : faire fonctionner l’application, améliorer nos services en mesurant l’efficacité de nos contenus et afficher des publicités susceptibles de vous intéresser.<br></p>\n<p>En cliquant sur “Accepter et fermer”, vous acceptez cette utilisation sur l’application mobile. Vous pouvez également paramétrer vos choix en cliquant sur “Paramétrer mes choix” ou refuser ces cookies en cliquant sur “Continuer sans accepter”. Vous pouvez changer d’avis à tout moment depuis les paramètres de votre compte via l’onglet “Notifications et cookies”</p>\n",
                durationText = "<p>Nous conservons votre choix pendant 12 mois. Vous pouvez changer d’avis à tout moment depuis les paramètres de votre compte via l’onglet “Notification et cookies” tetetettetettetetstts</p>\n"
            )
        ),
        purposes = listOf(
            PurposeDTO(
                id = "purpose-required",
                order = 0,
                isRequired = true,
                isAccepted = PurposeStatusDTO.ACCEPTED,
                translations = listOf(
                    PurposeTranslationDTO(
                        id = "UUID",
                        language = "fr",
                        text = "<p>Ces traceurs sont nécessaire au fonctionnement de l’application. Ils permettent de vérifier la stabilité technique de l’application et de mesurer notre audience. Ces données ne sont utilisées que pour notre compte exclusif (en ne produisant que des données statistiques anonymes).</p>",
                        name = "Nécessaire"
                    )
                ),
                vendors = listOf(
                    VendorDTO(
                        id = "vendors-crashlytics",
                        order = 0,
                        isAccepted = true,
                        isRequired = true,
                        translations = listOf(
                            VendorTranslationDTO(
                                id = "UUID",
                                language = "fr",
                                text = "<p>Ces traceurs sont nécessaire au fonctionnement de l’application. Ils permettent de vérifier la stabilité technique de l’application et de mesurer notre audience. Ces données ne sont utilisées que pour notre compte exclusif (en ne produisant que des données statistiques anonymes).</p>"
                            )
                        )
                    ),
                    VendorDTO(
                        id = "vendors-matomo",
                        order = 1,
                        isAccepted = true,
                        isRequired = false,
                        translations = listOf(
                            VendorTranslationDTO(
                                id = "UUID",
                                language = "fr",
                                text = "<p>Ces traceurs sont nécessaire au fonctionnement de l’application. Ils permettent de vérifier la stabilité technique de l’application et de mesurer notre audience. Ces données ne sont utilisées que pour notre compte exclusif (en ne produisant que des données statistiques anonymes).</p>"
                            )
                        )
                    )
                )
            ),
            PurposeDTO(
                id = "purpose-advertising",
                order = 1,
                isRequired = false,
                isAccepted = PurposeStatusDTO.REJECTED,
                translations = listOf(
                    PurposeTranslationDTO(
                        id = "UUID",
                        language = "fr",
                        text = "<p>Ces traceurs sont nécessaires pour afficher des publicités susceptibles de vous intéresser. Ils permettent de mesurer l’efficacité de nos campagnes publicitaires et de personnaliser les publicités affichées.</p>",
                        name = "Publicité"
                    )
                ),
                vendors = listOf(
                    VendorDTO(
                        id = "vendors-admob",
                        order = 0,
                        isAccepted = true,
                        isRequired = false,
                        translations = listOf(
                            VendorTranslationDTO(
                                id = "UUID",
                                language = "fr",
                                text = "<p>Ces traceurs sont nécessaires pour afficher des publicités susceptibles de vous intéresser. Ils permettent de mesurer l’efficacité de nos campagnes publicitaires et de personnaliser les publicités affichées.</p>"
                            )
                        )
                    )
                )
            ),
            PurposeDTO(
                id = "purpose-analytics",
                order = 2,
                isRequired = false,
                isAccepted = PurposeStatusDTO.ACCEPTED,
                translations = listOf(
                    PurposeTranslationDTO(
                        id = "UUID",
                        language = "fr",
                        text = "<p>Ces traceurs sont nécessaires pour mesurer l’efficacité de nos contenus. Ils permettent de mesurer l’audience de l’application et de comprendre comment les utilisateurs interagissent avec l’application.</p>",
                        name = "Analyse"
                    )
                ),
                vendors = listOf(
                    VendorDTO(
                        id = "vendors-firebase",
                        order = 0,
                        isAccepted = true,
                        isRequired = false,
                        translations = listOf(
                            VendorTranslationDTO(
                                id = "UUID",
                                language = "fr",
                                text = "<p>Ces traceurs sont nécessaires pour mesurer l’efficacité de nos contenus. Ils permettent de mesurer l’audience de l’application et de comprendre comment les utilisateurs interagissent avec l’application.</p>"
                            )
                        )
                    )
                )
            ),
            PurposeDTO(
                id = "purpose-personalization",
                order = 3,
                isRequired = false,
                isAccepted = PurposeStatusDTO.ACCEPTED,
                translations = listOf(
                    PurposeTranslationDTO(
                        id = "UUID",
                        language = "fr",
                        text = "<p>Ces traceurs sont nécessaires pour mesurer l’efficacité de nos contenus. Ils permettent de mesurer l’audience de l’application et de comprendre comment les utilisateurs interagissent avec l’application.</p>",
                        name = "Personnalisation"
                    )
                ),
                vendors = listOf(
                    VendorDTO(
                        id = "vendors-firebase",
                        order = 0,
                        isAccepted = true,
                        isRequired = false,
                        translations = listOf(
                            VendorTranslationDTO(
                                id = "UUID",
                                language = "fr",
                                text = "<p>Ces traceurs sont nécessaires pour mesurer l’efficacité de nos contenus. Ils permettent de mesurer l’audience de l’application et de comprendre comment les utilisateurs interagissent avec l’application.</p>"
                            )
                        )
                    )
                )
            ),
            PurposeDTO(
                id = "purpose-social",
                order = 4,
                isRequired = false,
                isAccepted = PurposeStatusDTO.ACCEPTED,
                translations = listOf(
                    PurposeTranslationDTO(
                        id = "UUID",
                        language = "fr",
                        text = "<p>Ces traceurs sont nécessaires pour mesurer l’efficacité de nos contenus. Ils permettent de mesurer l’audience de l’application et de comprendre comment les utilisateurs interagissent avec l’application.</p>",
                        name = "Social"
                    )
                ),
                vendors = listOf(
                    VendorDTO(
                        id = "vendors-firebase",
                        order = 0,
                        isAccepted = true,
                        isRequired = false,
                        translations = listOf(
                            VendorTranslationDTO(
                                id = "UUID",
                                language = "fr",
                                text = "<p>Ces traceurs sont nécessaires pour mesurer l’efficacité de nos contenus. Ils permettent de mesurer l’audience de l’application et de comprendre comment les utilisateurs interagissent avec l’application.</p>"
                            )
                        )
                    )
                )
            )
        )
    )

    override suspend fun getConsentConfig(
        applicationID: String,
        installationID: String,
    ): Response<GetConsentConfigDTO> {
        return Response.success(consents)
    }

}