package fr.openium.consentium_ui.domain.repository

import fr.openium.consentium.domain.useCase.GetConsentiumUniqueInstallationIdUseCase
import fr.openium.consentium_ui.data.remote.ConsentiumUIApi
import fr.openium.consentium_ui.domain.adapter.toConsentConfigData
import fr.openium.consentium_ui.domain.model.ContentConfigData
import javax.inject.Inject

internal class ConsentiumRepository @Inject constructor(
    private val getConsentiumUniqueInstallationIdUseCase: GetConsentiumUniqueInstallationIdUseCase,
    private val consentiumUIApi: ConsentiumUIApi,
) {
    suspend fun getConsentiumConfig(
        applicationId: String,
    ): ConsentiumUIRepositoryResponse {
        val installationId = getConsentiumUniqueInstallationIdUseCase.invoke()
        val consentsResponse = consentiumUIApi.getConsentConfig(applicationId, installationId)

        return try {
            val consentsBody = if (consentsResponse.isSuccessful) {
                consentsResponse.body() ?: throw Exception()
            } else {
                throw Exception()
            }

            ConsentiumUIRepositoryResponse.Success(consentsBody.toConsentConfigData())
        } catch (e: Exception) {
            ConsentiumUIRepositoryResponse.Error
        }
    }

}

internal interface ConsentiumUIRepositoryResponse {

    data object Error : ConsentiumUIRepositoryResponse

    data class Success(val contentConfigData: ContentConfigData) : ConsentiumUIRepositoryResponse

}