package fr.openium.consentium_ui.ui.utils

import android.text.ParcelableSpan
import android.text.Spanned
import androidx.compose.ui.text.AnnotatedString
import androidx.compose.ui.text.SpanStyle
import androidx.compose.ui.text.buildAnnotatedString
import androidx.compose.ui.text.style.TextDecoration
import androidx.compose.ui.text.withStyle
import androidx.core.text.HtmlCompat

fun htmlToAnnotatedString(html: String): AnnotatedString {
    val spanned: Spanned = HtmlCompat.fromHtml(html, HtmlCompat.FROM_HTML_MODE_LEGACY)
    return buildAnnotatedString {
        val text = spanned.toString()
        var start = 0
        spanned.getSpans(0, spanned.length, Any::class.java).map { it as ParcelableSpan }.forEach { span ->
            val startSpan = spanned.getSpanStart(span)
            val endSpan = spanned.getSpanEnd(span)

            // Ajoutez le texte précédent sans style
            if (start < startSpan) {
                append(text.substring(start, startSpan))
            }

            // Ajoutez le texte stylé
            withStyle(style = span.toSpanStyle()) {
                append(text.substring(startSpan, endSpan))
            }
            start = endSpan
        }

        // Ajoutez le texte restant sans style
        if (start < text.length) {
            append(text.substring(start, text.length).trimEnd())
        }
    }
}

fun ParcelableSpan.toSpanStyle(): SpanStyle {
    return when (this) {
        is android.text.style.StyleSpan -> {
            when (style) {
                android.graphics.Typeface.BOLD -> SpanStyle(fontWeight = androidx.compose.ui.text.font.FontWeight.Bold)
                android.graphics.Typeface.ITALIC -> SpanStyle(fontStyle = androidx.compose.ui.text.font.FontStyle.Italic)
                else -> SpanStyle()
            }
        }

        is android.text.style.UnderlineSpan -> SpanStyle(textDecoration = TextDecoration.Underline)
        is android.text.style.StrikethroughSpan -> SpanStyle(textDecoration = TextDecoration.LineThrough)
        else -> SpanStyle()
    }
}