package fr.openium.consentium.data.remote.mock

import fr.openium.consentium.data.remote.ConsentiumApi
import fr.openium.consentium.data.remote.model.GetConsent
import fr.openium.consentium.data.remote.model.PatchConsent
import kotlinx.coroutines.delay
import retrofit2.Response
import java.util.UUID

internal object ConsentiumMockApi : ConsentiumApi {

    private val consents = GetConsent.GetConsentPayloadDTO(
        installationId = UUID.randomUUID().toString(),
        purposes = listOf(
            GetConsent.PurposeDTO(
                identifier = "purpose-audience",
                isRequired = true,
                isAccepted = GetConsent.PurposeStatusDTO.ACCEPTED,
                vendors = listOf(
                    GetConsent.VendorDTO(
                        identifier = "vendor-clarity",
                        isAccepted = true,
                        isRequired = true,
                    ),
                    GetConsent.VendorDTO(
                        identifier = "vendor-matomo",
                        isAccepted = true,
                        isRequired = false,
                    )
                )
            ),
            GetConsent.PurposeDTO(
                identifier = "purpose-required",
                isRequired = true,
                isAccepted = GetConsent.PurposeStatusDTO.REJECTED,
                vendors = null
            ),
        ),
        isValid = false,
    )

    override suspend fun getConsents(applicationId: String, installationId: String): Response<GetConsent.GetConsentPayloadDTO> {
        delay(2000)
        return Response.success(consents)
    }

    override suspend fun setConsents(applicationId: String, patchConsent: PatchConsent.PatchConsentPayloadDTO): Response<Any> {
        delay(2000)
        return Response.success(Unit)
    }

}