package fr.openium.consentium.domain.repository

import fr.openium.consentium.api.adapter.toPatchConsentPurposeDTO
import fr.openium.consentium.api.adapter.toPurpose
import fr.openium.consentium.api.model.Purpose
import fr.openium.consentium.api.model.PurposeChoice
import fr.openium.consentium.data.local.ConsentiumDataStore
import fr.openium.consentium.data.remote.ConsentiumApi
import fr.openium.consentium.data.remote.model.PatchConsent
import javax.inject.Inject

internal class ConsentiumRepository @Inject constructor(
    private val consentiumApi: ConsentiumApi,
    private val consentiumDataStore: ConsentiumDataStore,
) {

    suspend fun getConsents(applicationId: String): ConsentiumRepositoryGetResponse {
        val installationId = consentiumDataStore.getInstallationUniqueId()
        val consentsResponse = consentiumApi.getConsents(applicationId, installationId)
        return try {
            val consentsBody = if (consentsResponse.isSuccessful) {
                consentsResponse.body() ?: throw Exception()
            } else {
                throw Exception()
            }

            return ConsentiumRepositoryGetResponse.GetConsentsSuccess(
                isValid = consentsBody.isValid,
                purposes = consentsBody.purposes?.map { purpose -> purpose.toPurpose() } ?: emptyList()
            )
        } catch (e: Exception) {
            ConsentiumRepositoryGetResponse.Error
        }
    }

    suspend fun setConsents(
        applicationId: String,
        consents: List<PurposeChoice>,
    ): ConsentiumRepositorySetResponse {
        val installationId = consentiumDataStore.getInstallationUniqueId()

        val setConsentResponse = consentiumApi.setConsents(
            applicationId = applicationId,
            patchConsent = PatchConsent.PatchConsentPayloadDTO(
                installationId = installationId,
                purposes = consents.map { it.toPatchConsentPurposeDTO() },
            )
        )

        return if (setConsentResponse.isSuccessful) {
            ConsentiumRepositorySetResponse.SetConsentsSuccess
        } else {
            ConsentiumRepositorySetResponse.Error
        }
    }

}

internal interface ConsentiumRepositoryGetResponse {

    data object Error : ConsentiumRepositoryGetResponse

    data class GetConsentsSuccess(
        val isValid: Boolean,
        val purposes: List<Purpose>,
    ) : ConsentiumRepositoryGetResponse

}

internal interface ConsentiumRepositorySetResponse {

    data object Error : ConsentiumRepositorySetResponse

    data object SetConsentsSuccess : ConsentiumRepositorySetResponse

}